cosmpy.protos.ibc.core.channel package — cosmpy documentation

# cosmpy.protos.ibc.core.channel package

## Subpackages

- cosmpy.protos.ibc.core.channel.v1 package
  - Submodules
  - cosmpy.protos.ibc.core.channel.v1.channel_pb2 module
  - cosmpy.protos.ibc.core.channel.v1.channel_pb2_grpc module
  - cosmpy.protos.ibc.core.channel.v1.genesis_pb2 module
  - cosmpy.protos.ibc.core.channel.v1.genesis_pb2_grpc module
  - cosmpy.protos.ibc.core.channel.v1.query_pb2 module
  - cosmpy.protos.ibc.core.channel.v1.query_pb2_grpc module
  - cosmpy.protos.ibc.core.channel.v1.tx_pb2 module
  - cosmpy.protos.ibc.core.channel.v1.tx_pb2_grpc module
  - Module contents

## Module contents